import { AccessToken } from '../models/AccessToken';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class GroupOrders {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a single group order token.
     * Check out the {@link https://ordercloud.io/api-reference/orders-and-fulfillment/group-orders/get-token|api docs} for more info
     *
     * @param invitationID ID of the invitation.
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetToken<TAccessToken extends AccessToken>(invitationID: string, requestOptions?: RequestOptions): Promise<RequiredDeep<TAccessToken>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * GroupOrders.As().List() // lists GroupOrders using the impersonated users' token
     */
    As(): this;
}
declare const _default: GroupOrders;
export default _default;
